@@ -17,7 +17,6 @@ from bin.justifytest import JustifyTest
 
 
 def main():
-    """
     print "Running TextTest"
     TextTest()
     print "Running TrueTypeTest"
@@ -44,14 +43,12 @@ def main():
     EllipseTest()
     print "Running TransormTest"
     TransformTest()
-    """
     print "Running HTMLTest"
     HtmlTest()
-    #print "Running HTMLTest2"
-    #HtmlTest2()
-    #print "Running Justify Test"
-    #JustifyTest()
-
+    print "Running HTMLTest2"
+    HtmlTest2()
+    print "Running Justify Test"
+    JustifyTest()
 
 if __name__ == '__main__':
     main()
